@@ -1,4 +1,4 @@
-from typing import Iterable, List, Mapping, Optional, Sequence, Set
+from typing import Iterable, List, Optional, Sequence, Set
 from cp93pytools.methodtools import cached_property
 import pyhash
 import numpy as np
